==> ejc-wzxt-api-3.0.0-20210902.074434-108-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailsVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 现场验收明细VO
 * 
 * @author generator
 * 
 */
public class CheckDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String projectName; // 项目名称
    private String projectInstoreName; // 项目仓库名称
    private String billCode; // 单据编号
    private String supplierName; // 供应商名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkDate; // 验收日期
    private String checkType; // 业务类型
    private String employeeName; // 验收人
    private String licensePlate; // 车牌号
    private Integer billState; // 单据状态（审批必须字段）
    private Integer useState; // 引用状态（0-未引用，1-已引用）
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private String unit; // 单位
    private BigDecimal checkNumsSum; // 验收数量
    private BigDecimal deliverNumsSum; // 发货数量
    private Long orgId; // 组织
    private String billStateName; // 单据状态名称
    private String checkTypeName; // 业务类型名称
    private String useStateName; // 引用状态名称

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getCheckTypeName() {
        return checkTypeName;
    }

    public void setCheckTypeName(String checkTypeName) {
        this.checkTypeName = checkTypeName;
    }

    public String getUseStateName() {
        return useStateName;
    }

    public void setUseStateName(String useStateName) {
        this.useStateName = useStateName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectInstoreName() {
        return projectInstoreName;
    }

    public void setProjectInstoreName(String projectInstoreName) {
        this.projectInstoreName = projectInstoreName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Date getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(Date checkDate) {
        this.checkDate = checkDate;
    }

    public String getCheckType() {
        return checkType;
    }

    public void setCheckType(String checkType) {
        this.checkType = checkType;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getLicensePlate() {
        return licensePlate;
    }

    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Integer getUseState() {
        return useState;
    }

    public void setUseState(Integer useState) {
        this.useState = useState;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }

    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
}

==> ejc-wzxt-api-3.0.0-20241120.090420-173-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailsVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 现场验收明细VO
 * 
 * @author generator
 * 
 */
public class CheckDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String projectName; // 项目名称
    private String projectInstoreName; // 项目仓库名称
    private String billCode; // 单据编号
    private String supplierName; // 供应商名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkDate; // 验收日期
    private String checkType; // 业务类型
    private String employeeName; // 验收人
    private String licensePlate; // 车牌号
    private Integer billState; // 单据状态（审批必须字段）
    private Integer useState; // 引用状态（0-未引用，1-已引用）
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private String unit; // 单位
    private BigDecimal checkNumsSum; // 验收数量
    private BigDecimal deliverNumsSum; // 发货数量
    private Long orgId; // 组织
    private String billStateName; // 单据状态名称
    private String checkTypeName; // 业务类型名称
    private String useStateName; // 引用状态名称
    private BigDecimal orderNumsSum; // 订单数量
    private String construction; // 使用部位
    private String supplierUserName; // 供应商联系人名称
    private String supplierUserMobile; // 供应商联系人电话


    public BigDecimal getOrderNumsSum() {
        return orderNumsSum;
    }

    public void setOrderNumsSum(BigDecimal orderNumsSum) {
        this.orderNumsSum = orderNumsSum;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public String getSupplierUserName() {
        return supplierUserName;
    }

    public void setSupplierUserName(String supplierUserName) {
        this.supplierUserName = supplierUserName;
    }

    public String getSupplierUserMobile() {
        return supplierUserMobile;
    }

    public void setSupplierUserMobile(String supplierUserMobile) {
        this.supplierUserMobile = supplierUserMobile;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getCheckTypeName() {
        return checkTypeName;
    }

    public void setCheckTypeName(String checkTypeName) {
        this.checkTypeName = checkTypeName;
    }

    public String getUseStateName() {
        return useStateName;
    }

    public void setUseStateName(String useStateName) {
        this.useStateName = useStateName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectInstoreName() {
        return projectInstoreName;
    }

    public void setProjectInstoreName(String projectInstoreName) {
        this.projectInstoreName = projectInstoreName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Date getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(Date checkDate) {
        this.checkDate = checkDate;
    }

    public String getCheckType() {
        return checkType;
    }

    public void setCheckType(String checkType) {
        this.checkType = checkType;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getLicensePlate() {
        return licensePlate;
    }

    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Integer getUseState() {
        return useState;
    }

    public void setUseState(Integer useState) {
        this.useState = useState;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }

    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
}
